@@ -69,7 +69,6 @@ class wireless(object):
 
     async def Get_NetworkWirelessSsidFirewallL3FirewallRules(self, db: object,
                                                              net_id: str,
-
                                                              _appcfg: object):
         ssids_l3 = []
         for ssid_num in range(0, 15):
@@ -199,8 +198,7 @@ class wireless(object):
                                                                 **temp_SSID)
                     self.ReSync = True
                     if self.ReSync or not appcfg.CLEAN:
-                        await self.Get_NetworkWirelessSsid(db, net_id,
-                                                           self, appcfg)
+                        await self.Get_NetworkWirelessSsid(db, net_id,appcfg)
                         appcfg.CLEAN = True
                         self.ReSync = False
 
@@ -327,7 +325,7 @@ class wireless(object):
                         self.ReSync = True
 
                         await self.Get_NetworkWirelessSsidTrafficShapingRules(
-                            db, net_id, self, appcfg)
+                            db, net_id, appcfg)
                         appcfg.CLEAN = True
                         self.ReSync = False
                 except Exception as e:
@@ -529,7 +527,7 @@ class wireless(object):
                                 f'{lib.bc.FAIL}{netName} - {task} \t\t{lib.bc.FAIL}iPSK already created or still there{lib.bc.ENDC}')
 
         if self.ReSync or not appcfg.CLEAN:
-            await self.Get_NetworkWirelessSsidIdentityPsks(db, net_id)
+            await self.Get_NetworkWirelessSsidIdentityPsks(db, net_id, appcfg)
             appcfg.CLEAN = True
             self.ReSync = False
 
